# gislib


This is a python package for GIS operations in Python.

## Installation

> pip install gislib
 
 or

> conda install -c iamsaswata gislib

or 

> pip install git+https://github.com/iamsaswata/gislib.git


## License

gislib is available under the [MIT](https://opensource.org/licenses/MIT) license.
